==> redi-0.14.3.tar.gz: redi-0.14.3/README.md <==
RED-I Project
=============

<a href="http://dx.doi.org/10.5281/zenodo.17125"><img src="https://zenodo.org/badge/4064/ctsit/redi.svg"><a>
[![Travis CI](https://api.travis-ci.org/ctsit/redi.svg?branch=master)](https://api.travis-ci.org/ctsit/redi.svg?branch=master)
[![Version](https://pypip.in/v/redi/badge.png)](https://pypip.in/v/redi/badge.png)
[![Coverage Status Master](https://coveralls.io/repos/ctsit/redi/badge.svg?branch=master)](https://coveralls.io/r/ctsit/redi?branch=master)
[![Coverage Status Develop](https://coveralls.io/repos/ctsit/redi/badge.svg?branch=develop)](https://coveralls.io/r/ctsit/redi?branch=develop)
[![Downloads](https://pypip.in/d/redi/badge.png)](https://pypip.in/d/redi/badge.png)


Introduction
------------

The REDCap Electronic Data Importer (RED-I) is a tool which is used to
automate the process of loading clinical data from Electronic Medical
Records (EMR) systems into [REDCap](http://www.project-redcap.org/)
Study data capture systems. RED-I is a general purpose tool for REDCap
data importing suitable for use on any study in any REDCap system. It
uses XML lookups to translate data stored in comma separated values
(CSV) files and uploads it to a REDCAP Server using the REDCap API. The
tool allows study data to be securely uploaded from clinical reporting
systems, error checked, and uploaded into REDCap. It provides the
investigator with feedback on upload success in the form of summary
reporting of the data upload process.

You can view a presentation of the RED-I tool in action on
[youtube](https://www.youtube.com/watch?v=0x04y5SNPL8&feature=youtu.be)

For the official documentation please refer to
[http://redi.readthedocs.org](http://redi.readthedocs.org) or
[RED-I Project](https://github.com/ctsit/redi/blob/master/docs/about.rst).

==> redi-0.15.5.tar.gz: redi-0.15.5/README.md <==
RED-I Project
=============

[![10.5281/zenodo.47793](https://zenodo.org/badge/4064/ctsit/redi.svg)](http://ufl.to/ctsit)
[![Travis CI](https://api.travis-ci.org/ctsit/redi.svg?branch=master)](https://api.travis-ci.org/ctsit/redi.svg?branch=master)
[![PyPI version](https://badge.fury.io/py/redi.svg)](https://badge.fury.io/py/redi)
[![Coverage Status Develop](https://coveralls.io/repos/ctsit/redi/badge.svg?branch=master)](https://coveralls.io/r/ctsit/redi?branch=master)


Introduction
------------

The REDCap Electronic Data Importer (RED-I) is a tool which is used to
automate the process of loading clinical data from Electronic Medical
Records (EMR) systems into [REDCap](http://www.project-redcap.org/)
Study data capture systems. RED-I is a general purpose tool for REDCap
data importing suitable for use on any study in any REDCap system. It
uses XML lookups to translate data stored in comma separated values
(CSV) files and uploads it to a REDCAP Server using the REDCap API. The
tool allows study data to be securely uploaded from clinical reporting
systems, error checked, and uploaded into REDCap. It provides the
investigator with feedback on upload success in the form of summary
reporting of the data upload process.

You can view a presentation of the RED-I tool in action on
[youtube](https://www.youtube.com/watch?v=0x04y5SNPL8&feature=youtu.be).

For the official documentation please refer to
[http://redi.readthedocs.io](http://redi.readthedocs.io) or
[RED-I Project](https://github.com/ctsit/redi/blob/master/docs/about.rst).
